@@ -193,7 +193,7 @@ visualize_keywords <- function(docs, keywords, prune = TRUE, label_size = 3.2) {
   unlisted <- unlist(docs$W_raw, recursive = FALSE, use.names = FALSE)
 
   # Check keywords
-  keywords <- check_keywords(unique(unlisted), keywords, prune)
+  keywords <- check_keywords(unique(unlisted), keywords, prune)$keywords
 
   # Organize data
   unnested_data <- tibble::tibble(text_split = unlisted)
@@ -287,7 +287,13 @@ visualize_keywords <- function(docs, keywords, prune = TRUE, label_size = 3.2) {
   return(keyATM_viz)
 }
 
-get_empty_index <- function(unique_words, keywords, prune = TRUE) {
+
+check_keywords <- function(
+  unique_words,
+  keywords,
+  prune = TRUE,
+  stop_if_all_pruned = TRUE
+) {
   # Prune keywords that do not appear in the corpus
   keywords_flat <- unlist(keywords, use.names = FALSE, recursive = FALSE)
   non_existent <- keywords_flat[!keywords_flat %in% unique_words]
@@ -314,28 +320,25 @@ get_empty_index <- function(unique_words, keywords, prune = TRUE) {
     }
   }
   num_keywords <- unlist(lapply(keywords, length))
-  allzero_index <- which(as.vector(num_keywords) == 0)
-  return(allzero_index)
-}
+  all_pruned_topic_idx <- which(as.vector(num_keywords) == 0)
 
-check_keywords <- function(unique_words, keywords, prune) {
-  check_zero <- get_empty_index(unique_words, keywords, prune)
-  if (length(check_zero) != 0) {
-    zero_names <- names(keywords)[check_zero]
+  if (stop_if_all_pruned && length(all_pruned_topic_idx) != 0) {
+    zero_names <- names(keywords)[all_pruned_topic_idx]
     cli::cli_abort(paste0(
       "All keywords are pruned. Please check: ",
       paste(zero_names, collapse = ", ")
     ))
   }
 
-  return(keywords)
+  return(list(keywords = keywords, all_pruned_topic_idx = all_pruned_topic_idx))
 }
 
 #' Refine keywords
 #'
-#' Refine keywords by dropping topics that does not have any occurence in the documents.
+#' Refine keywords by (1) dropping keywords that do not appear in the documents and (2) dropping topics that does not have any occurence in the documents.
 #' @param keywords a list of keywords
 #' @param docs a keyATM_docs object, generated by \code{keyATM_read()} function
+#' @param prune logical, whether to prune keywords that do not appear in the documents
 #' @export
 #' @return a list of refined keywords
 #' @examples
@@ -348,7 +351,7 @@ check_keywords <- function(unique_words, keywords, prune) {
 #'   bills_keywords$Videogame <- c("metroid", "castlevania", "balatro")
 #'   refine_keywords(bills_keywords, keyATM_docs)
 #' }
-refine_keywords <- function(keywords, docs) {
+refine_keywords <- function(keywords, docs, prune = TRUE) {
   if (is.null(docs$wd_names)) {
     unique_words <- unique(unlist(
       docs$W_raw,
@@ -359,11 +362,19 @@ refine_keywords <- function(keywords, docs) {
   } else {
     unique_words <- docs$wd_names
   }
-  check_zero <- get_empty_index(unique_words, keywords, prune = TRUE)
+  checked <- check_keywords(
+    unique_words,
+    keywords,
+    prune = prune,
+    stop_if_all_pruned = FALSE
+  )
+  keywords_checked <- checked$keywords
+  check_zero <- checked$all_pruned_topic_idx
+
   if (length(check_zero) == length(keywords)) {
     cli::cli_abort("Nothing left in `keywords`!")
   }
-  return(keywords[setdiff(seq_along(keywords), check_zero)])
+  return(keywords_checked[setdiff(seq_along(keywords), check_zero)])
 }
 
 get_doc_index <- function(W_raw, check = FALSE) {
@@ -495,7 +506,7 @@ keyATM_initialize <- function(
   }
 
   # Check keywords
-  keywords <- check_keywords(info$wd_names, keywords, options$prune)
+  keywords <- check_keywords(info$wd_names, keywords, options$prune)$keywords
 
   keywords_raw <- keywords # keep raw keywords (not word_id)
   keywords_id <- lapply(keywords, function(x) {
